==> haskell-servant-swagger-1.2.1-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-swagger
version:              1.2.1
visibility:           public
id:                   servant-swagger-1.2.1-24zVvtiLJr8LJvUxqwfEmm
key:                  servant-swagger-1.2.1-24zVvtiLJr8LJvUxqwfEmm
license:              BSD-3-Clause
copyright:            (c) 2015-2018, Servant contributors
maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:
    https://github.com/haskell-servant/servant/tree/master/servant-swagger#readme

synopsis:
    Generate a Swagger/OpenAPI/OAS 2.0 specification for your servant API.

description:
    Swagger is a project used to describe and document RESTful APIs. The core of the
    project is the [OpenAPI Specification (OAS)](https://swagger.io/docs/specification/about/).
    This library implements v2.0 of the spec. Unlike Servant it is language-agnostic and thus is
    quite popular among developers in different languages. It has also existed for a longer time
    and has more helpful tooling.

    This package provides means to generate a Swagger/OAS specification for a Servant API
    and also to partially test whether an API conforms with its specification.

    Generated Swagger specification then can be used for many things such as

    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);

    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);

    * and [many others](http://swagger.io/open-source-integrations/).

category:             Web, Servant, Swagger
abi:                  86cf32d65edeb387fd5fc53c4792a7b6
exposed:              True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-swagger
hs-libraries:         HSservant-swagger-1.2.1-24zVvtiLJr8LJvUxqwfEmm
depends:
    QuickCheck-2.14.3-H48j1VoMzL8JGNazf5xEmB
    aeson-2.1.2.1-4xKrNuS491zGhSp7DRfhkt
    aeson-pretty-0.8.10-3D4GDckc4v7CyGZorD0IoD base-4.17.2.1
    base-compat-0.12.2-3peTS4EQIw912qC0ETmbL5 bytestring-0.11.5.3
    hspec-2.10.9-C6fPeSHqRtyA1hXE5bbkV
    http-media-0.8.1.1-7gQ18NkqHc7Ahs6yM1xJkk
    insert-ordered-containers-0.2.5.3-CRAXT2xtmir389FFwPIfoJ
    lens-5.2.3-KfchkrYqe7G7U6wvL6YyJ5
    servant-0.20.2-5Sqarx6dqXeEQupv4LcMFv
    singleton-bool-0.1.7-D70XRkHP0H17VRNE9AczhM
    swagger2-2.8.9-34MHWePMN4f95lhVHCLzIt text-2.0.2
    unordered-containers-0.2.20-Ko0oshTaIwM77y5vt748zM

haddock-interfaces:
    /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock

haddock-html:         /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-swagger-1.2.1-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-swagger
version:              1.2.1
visibility:           public
id:                   servant-swagger-1.2.1-BFfFEyqgzTwFotF5dckUot
key:                  servant-swagger-1.2.1-BFfFEyqgzTwFotF5dckUot
license:              BSD-3-Clause
copyright:            (c) 2015-2018, Servant contributors
maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:
    https://github.com/haskell-servant/servant/tree/master/servant-swagger#readme

synopsis:
    Generate a Swagger/OpenAPI/OAS 2.0 specification for your servant API.

description:
    Swagger is a project used to describe and document RESTful APIs. The core of the
    project is the [OpenAPI Specification (OAS)](https://swagger.io/docs/specification/about/).
    This library implements v2.0 of the spec. Unlike Servant it is language-agnostic and thus is
    quite popular among developers in different languages. It has also existed for a longer time
    and has more helpful tooling.

    This package provides means to generate a Swagger/OAS specification for a Servant API
    and also to partially test whether an API conforms with its specification.

    Generated Swagger specification then can be used for many things such as

    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);

    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);

    * and [many others](http://swagger.io/open-source-integrations/).

category:             Web, Servant, Swagger
abi:                  a936b89d77f3d7973e60637668a091bd
exposed:              True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-swagger
hs-libraries:         HSservant-swagger-1.2.1-BFfFEyqgzTwFotF5dckUot
depends:
    QuickCheck-2.14.3-9Q0kCzH4SfmKZwwhPvduaz
    aeson-2.1.2.1-JUxXPniSz0YG5YB65a9rRK
    aeson-pretty-0.8.10-16lJurEf1YvFr0OK8k3g2S base-4.17.2.1
    base-compat-0.12.2-3peTS4EQIw912qC0ETmbL5 bytestring-0.11.5.3
    hspec-2.10.9-LFxAr7Wn9ofEhyFifx4TyA
    http-media-0.8.1.1-DpUzfs6TvN2FBjwxqs8EYh
    insert-ordered-containers-0.2.5.3-zgDu8lHIFI3oAqiNeE3Ae
    lens-5.2.3-7xTAGVF8ixt9yux1447c6O
    servant-0.20.2-M198Qbz1Py1RMtJkhCm2Y
    singleton-bool-0.1.7-D70XRkHP0H17VRNE9AczhM
    swagger2-2.8.9-4MjiKPlASYAEGHRi59bJY text-2.0.2
    unordered-containers-0.2.20-1FuCl8JL5xL639QhRwjqcc

haddock-interfaces:
    /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock

haddock-html:         /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
